@@ -852,9 +852,16 @@ def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
     print(credentials)
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-    return s3_client.list_objects_v2(
-        Bucket=bucket,
-        Delimiter=delimiter,
-        MaxKeys=max_keys,
-        Prefix=prefix,
-        ContinuationToken=token)
+    if token:
+        return s3_client.list_objects_v2(
+            Bucket=bucket,
+            Delimiter=delimiter,
+            MaxKeys=max_keys,
+            Prefix=prefix,
+            ContinuationToken=token)
+    else:
+        return s3_client.list_objects_v2(
+            Bucket=bucket,
+            Delimiter=delimiter,
+            MaxKeys=max_keys,
+            Prefix=prefix)
